@@ -1,10 +1,11 @@
 /****************************************************************************
- *
- * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
- *
- * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
- *
+ #
+ # Copyright (c) 1996-2023 Vladi Belperchinov-Shabanski "Cade" 
+ # https://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
+ # https://cade.noxrun.com/projects/vfu     https://github.com/cade-vs/vfu
+ #
+ # SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
+ #
  ****************************************************************************/
 
 #include <string.h>
@@ -22,26 +23,24 @@
 
   char HEXCHARS[] = "0123456789ABCDEF";
 
-  char bg_xlat_table[2][64] =
+  static char bg_xlat_table[2][64] =
   {
   "?",
   "abwgdevzijklmnoprstufhc`[]yxuqABWGDEVZIJKLMNOPRSTUFHC`[]YXUQ"
   };
 
-  char bgw_xlat_table[2][64] =
+  static char bgw_xlat_table[2][64] =
   {
   "",
   "abwgdevzijklmnoprstufhc`[]yxuqABWGDEVZIJKLMNOPRSTUFHC`[]YXUQ"
   };
 
-  #define MAXCOLS 1024
-
 /*--------------------------------------------------------------------*/
 
   SeeViewer::SeeViewer( SeeViewerOptions *a_opt )
   {
     opt = a_opt;
-    memset( &escape_keys, 0, sizeof(escape_keys));
+    memset( &escape_keys, 0, sizeof( escape_keys ) );
     f = NULL;
     line = last_line = 1;
     col = 0;
@@ -51,7 +50,7 @@
     freezed = 0;
     do_draw = 0;
 
-    if ( opt->auto_size )
+    if( opt->auto_size )
       {
       opt->xmin = 1;
       opt->ymin = 1;
@@ -165,7 +164,7 @@
     else
       str_pad( str, -(cols-2) );
     str += "|";
-    con_out( opt->xmin, opt->ymax, str, opt->cs );
+    vfu_con_out( opt->xmin, opt->ymax, str, opt->cs );
   }
 
 /*--------------------------------------------------------------------*/
@@ -261,7 +260,7 @@
       if ( hexdump[0] == '~' ) line = "~";
 
       str_pad( line, -cols );
-      con_out( 1, y+1, line, (opt->grid && y % 2 == 0) ? opt->ch : opt->cn );
+      vfu_con_out( 1, y+1, line, (opt->grid && y % 2 == 0) ? opt->ch : opt->cn );
       }
 
     status( "%3.0f%% | Pos. %4" FMT_OFF_T "d of %4" FMT_OFF_T "d | Alt+H Help | %s",
@@ -289,7 +288,7 @@
         {
         str = "~";
         str_pad( str, -cols );
-        con_out( 1, y+1, str, (opt->grid && y%2==0) ? opt->ch : opt->cn );
+        vfu_con_out( 1, y+1, str, (opt->grid && y%2==0) ? opt->ch : opt->cn );
         continue;
         }
 
@@ -297,6 +296,7 @@
       while ( z > 0 && ( buff[z-1] == '\r' || buff[z-1] == '\n' ) ) z--;
       buff[z] = 0;
       filter( buff, z );
+      WString www = buff;
 
       int show_lmark = 0;
       int show_rmark = 0;
@@ -306,34 +306,39 @@
         {
         if (col >= z)
           {
-          buff[0] = 0;
+          // buff[0] = 0;
+          www = L"";
           show_lmark = 1;
           z = 0;
           }
         else
           {
-          str_trim_left( buff, col );
+          // str_trim_left( buff, col );
+          str_trim_left( www, col );
           z -= col;
           }
         }
+      
       if ( z > cols )
         {
-        buff[cols] = 0;
+        // buff[cols] = 0;
+        str_sleft( www, cols );
         show_rmark = 1;
         }
       else
         {
         if ( opt->show_eol && !show_lmark ) show_eol = z+1;
         }
-      str_pad( buff, -cols );
-      con_out( 1, opt->ymin+y, buff, (opt->grid && y%2==0) ? opt->ch : opt->cn);
+      //str_pad( buff, -cols );
+      str_pad( www, -cols );
+      vfu_con_out( 1, opt->ymin+y, VString( www ), (opt->grid && y%2==0) ? opt->ch : opt->cn);
 
       if ( re.ok() && re.m( buff ) )
-        con_out( re.sub_sp(0)+1, opt->ymin+y, re.sub(0), CONCOLOR( cBLACK, cWHITE ) );
+        vfu_con_out( re.sub_sp(0)+1, opt->ymin+y, re.sub(0), CONCOLOR( cBLACK, cWHITE ) );
 
-      if (show_lmark) con_out(1,opt->ymin+y,"<",chRED);
-      if (show_rmark) con_out( opt->xmax, opt->ymin+y, ">", chRED );
-      if (show_eol != -1) con_out( show_eol, opt->ymin+y, "$", chGREEN );
+      if (show_lmark) vfu_con_out(1,opt->ymin+y,"<",chRED);
+      if (show_rmark) vfu_con_out( opt->xmax, opt->ymin+y, ">", chRED );
+      if (show_eol != -1) vfu_con_out( show_eol, opt->ymin+y, "$", chGREEN );
       }
     status( "%3.0f%% | Pos. %4" FMT_OFF_T "d | Line %4" FMT_OFF_T "d of %4" FMT_OFF_T "d%c|%4d+ | Alt+H Help | %s",
             fpos_percent(), fpos, line, last_line,
@@ -345,8 +350,8 @@
   void SeeViewer::draw()
   {
     (opt->hex_mode) ? draw_hex() : draw_txt();
-    if ( xlat == 1 ) con_out( opt->xmax -  7, opt->ymin, "BG XLAT", chRED );
-    if ( xlat == 2 ) con_out( opt->xmax - 10, opt->ymin, "BGWIN XLAT", chRED );
+    if ( xlat == 1 ) vfu_con_out( opt->xmax -  7, opt->ymin, "BG XLAT", chRED );
+    if ( xlat == 2 ) vfu_con_out( opt->xmax - 10, opt->ymin, "BGWIN XLAT", chRED );
   }
 
 /*--------------------------------------------------------------------*/
@@ -467,11 +472,14 @@
     {
     sprintf( sss, "x%" FMT_OFF_T "X", fpos );
     status( " Goto pos: " );
-    if (!TextInput( 15, opt->ymax, "", 20, 20, &sss ))
+    WString www = sss;
+    if ( ! TextInput( 15, opt->ymax, "", 20, 20, www ) )
       {
       draw();
       return;
       }
+    sss = www;
+    
     off_t new_pos = fpos;
     str_cut_spc( sss );
     str_up( sss );
@@ -494,11 +502,13 @@
       }
     sprintf( sss, "%" FMT_OFF_T "d", line);
     status( " Goto line: " );
-    if (!TextInput( 15, opt->ymax, "", 20, 20, &sss ))
+    WString www = sss;
+    if (!TextInput( 15, opt->ymax, "", 20, 20, www ))
       {
       draw();
       return;
       }
+    sss = www;  
     off_t new_line = line;
     str_cut_spc( sss );
     str_up( sss );
@@ -538,7 +548,7 @@
 
 /*--------------------------------------------------------------------*/
 
-  int SeeViewer::find_next_hex( int rev )
+  int SeeViewer::find_next_hex( int rev __attribute__((unused)) )
   {
   //FIXME: implement!!!
   return 0;
@@ -597,12 +607,13 @@
   VString sss;
   status( "Find %s: ", opts );
   int ii = str_len(sss)+2;
-  sss = opt->last_search;
-  if(!TextInput( opt->xmin+ii, opt->ymax, "", opt->xmax-ii-4, opt->xmax-ii-4, &sss ))
+  WString www = opt->last_search;
+  if(!TextInput( opt->xmin+ii, opt->ymax, "", opt->xmax-ii-4, opt->xmax-ii-4, www ))
     {
     draw();
     return 1;
     }
+  sss = www;  
   str_sleft( sss, MAX_SEARCH_LEN );
   strcpy( opt->last_search, sss );
   strcpy( opt->last_opt, opts );
@@ -667,7 +678,7 @@
     switch( key )
       {
       case 9         : in_text = !in_text; break;
-      case KEY_RIGHT : if (bytepos == 0 && !in_text)
+      case UKEY_RIGHT : if (bytepos == 0 && !in_text)
                          bytepos = 1;
                        else
                          if (epos < editbs - 1)
@@ -676,7 +687,7 @@
                            if (!in_text) bytepos = 0;
                            }
                        break;
-      case KEY_LEFT  : if (bytepos == 1 && !in_text )
+      case UKEY_LEFT  : if (bytepos == 1 && !in_text )
                          bytepos = 0;
                        else
                          if (epos > 0)
@@ -685,16 +696,16 @@
                            if (!in_text) bytepos = 1;
                            }
                        break;
-      case KEY_DOWN  : if ( epos + rowsz <  editbs ) epos += rowsz; break;
-      case KEY_UP    : if ( epos - rowsz >= 0      ) epos -= rowsz; break;
+      case UKEY_DOWN  : if ( epos + rowsz <  editbs ) epos += rowsz; break;
+      case UKEY_UP    : if ( epos - rowsz >= 0      ) epos -= rowsz; break;
 
-      case KEY_PPAGE : epos = epos % rowsz; break;
-      case KEY_NPAGE : epos = editbs - editbs % rowsz + epos % rowsz;
+      case UKEY_PGUP : epos = epos % rowsz; break;
+      case UKEY_PGDN : epos = editbs - editbs % rowsz + epos % rowsz;
                        if (epos >= editbs) epos = editbs - 1;
                        break;
 
-      case KEY_HOME  : epos = epos - epos % rowsz; bytepos = 0; break;
-      case KEY_END   : epos = epos + (rowsz - epos%rowsz - 1);
+      case UKEY_HOME  : epos = epos - epos % rowsz; bytepos = 0; break;
+      case UKEY_END   : epos = epos + (rowsz - epos%rowsz - 1);
                        if (epos >= editbs) epos = editbs - 1;
                        break;
       }
@@ -716,7 +727,7 @@
       filter( tmp, 1 );
       con_xy( 13 + rowsz * 3 + (opt->hex_cols - 1) * 2 + 1 + epos % rowsz, 1 + epos / rowsz);
       con_puts( tmp, chRED );
-      key = KEY_RIGHT;
+      key = UKEY_RIGHT;
       }
     else
     if ( in_text && key >= 32 && key < 255 )
@@ -729,7 +740,7 @@
       tmp[2] = 0;
       con_puts( tmp, chRED );
       editb[epos] = key;
-      key = KEY_RIGHT;
+      key = UKEY_RIGHT;
       }
     else
       key = 0;
@@ -764,35 +775,35 @@
       do_draw = 0;
       }
     ch = con_getch();
-    if( ch == 0 ) ch = KEY_CTRL_L;
+    if( ch == 0 ) ch = UKEY_CTRL_L;
     if (  ch == 27        || ch == '-'           || ch == 'q' ||
-          ch == KEY_ALT_X || ch == KEY_BACKSPACE ) return ch;
+          ch == UKEY_ALT_X || ch == UKEY_BACKSPACE ) return ch;
     int z = 0;
     while( escape_keys[z] )
       if ( escape_keys[z++] == ch )
         return ch;
     switch(ch)
       {
-      case KEY_F1     :
-      case KEY_ALT_H  :
+      case UKEY_F1     :
+      case UKEY_ALT_H  :
       case '?'        :
       case 'h'        :
       case 'H'        : help(); break;
-      case KEY_UP     : up(); draw(); break;
+      case UKEY_UP     : up(); draw(); break;
       case 13         :
-      case KEY_DOWN   : down(); draw(); break;
+      case UKEY_DOWN   : down(); draw(); break;
       case 'b'        :
       case 'B'        :
-      case KEY_PPAGE  : for ( z = 0; z < rows; z++ ) up(); draw(); break;
+      case UKEY_PGUP  : for ( z = 0; z < rows; z++ ) up(); draw(); break;
       case ' '        :
-      case KEY_NPAGE  : for ( z = 0; z < rows; z++ ) down(); draw(); break;
+      case UKEY_PGDN  : for ( z = 0; z < rows; z++ ) down(); draw(); break;
       case 'p'        :
       case 'P'        :
-      case KEY_HOME   : if (fpos == 0) col = 0; else home(); draw(); break;
-      case KEY_END    : end();  draw(); break;
-      case KEY_CTRL_E : end2(); draw(); break;
+      case UKEY_HOME   : if (fpos == 0) col = 0; else home(); draw(); break;
+      case UKEY_END    : end();  draw(); break;
+      case UKEY_CTRL_E : end2(); draw(); break;
 
-      case KEY_CTRL_L : if ( opt->auto_size )
+      case UKEY_CTRL_L : if ( opt->auto_size )
                           {
                           opt->xmin = 1;
                           opt->ymin = 1;
@@ -807,7 +818,7 @@
 
       case '>'        :
       case '.'        :
-      case KEY_RIGHT  : if (opt->hex_mode)
+      case UKEY_RIGHT  : if (opt->hex_mode)
                           {
                           if (fpos < fsize) fpos++;
                           draw();
@@ -823,7 +834,7 @@
                         break;
       case '<'        :
       case ','        :
-      case KEY_LEFT   :
+      case UKEY_LEFT   :
                         if (opt->hex_mode)
                           {
                           if (fpos > 0) fpos--;
@@ -875,7 +886,7 @@
       case 'E'        : find( "fh" ); break;
       case '/'        : find( "r" ); break; //FIXME: remove 'r', use 'f'
       case '\\'       : find( "ri" ); break;
-      case KEY_F3     :
+      case UKEY_F3     :
       case 'n'        :
       case 'N'        : find_next( 0 ); break;
       case 'm'        :
@@ -923,7 +934,7 @@
                             ruler += z % 10;
                             }
                           str_sleft( ruler, opt->xmax );
-                          con_out( 1, 1, ruler, opt->ch );
+                          vfu_con_out( 1, 1, ruler, opt->ch );
                           }
                         break;
       case 'i'        :
@@ -1067,7 +1078,7 @@
   if (access( fname, F_OK ))
     {
     mod = 1;
-    va.push( "" ); /* hack if new file */
+    va.push( L"" ); /* hack if new file */
     }
   sv.set_min_max( 0, va.count() - 1 );
   sv.go( 0 );
@@ -1110,7 +1121,7 @@
     else
       str_pad( str, -(cols-2) );
     str += "|";
-    con_out( opt->xmin, opt->ymax, str, opt->cs );
+    vfu_con_out( opt->xmin, opt->ymax, str, opt->cs );
     set_cursor();
   }
 
@@ -1175,7 +1186,7 @@
     {
     VString sss = "~";
     str_pad( sss, - cols );
-    con_out( 1, ( n - sv.page() ) + 1, sss, opt->cn );
+    vfu_con_out( 1, ( n - sv.page() ) + 1, sss, opt->cn );
     }
   else
     {
@@ -1185,7 +1196,7 @@
     str_trim_left( str, colpage );
     str_sleft( str, cols );
     str_pad( str, - cols );
-    con_out( 1, ( n - sv.page() ) + 1, str, opt->cn );
+    vfu_con_out( 1, ( n - sv.page() ) + 1, str, opt->cn );
     }
   set_cursor();
   }
@@ -1387,10 +1398,10 @@
   void SeeEditor::kenter()
   {
   mod = 1;
-  if ( va.count() == 0 ) va.push( "" );
+  if ( va.count() == 0 ) va.push( L"" );
   int c = real_col();
-  VString str = va[sv.pos()];
-  VString nstr = str;
+  WString str = va[sv.pos()];
+  WString nstr = str;
   str_sleft( str, c );
   str_trim_left( nstr, c );
   va.set( sv.pos(), str );
@@ -1403,14 +1414,14 @@
     str = va[sv.pos()-1];
     int z = 0;
     int nc = 0;
-    while( z < str_len(str) && (str[z] == ' ' || str[z] == '\t') )
+    while( z < str_len(str) && (str[z] == L' ' || str[z] == L'\t') )
       {
-      if ( str[z] == '\t' ) nc += opt->tabsize; else nc++;
+      if ( str[z] == L'\t' ) nc += opt->tabsize; else nc++;
       z++;
       }
     str = va[sv.pos()];
     col = nc;
-    while( nc-- ) str_ins_ch( str, 0, ' ' );
+    while( nc-- ) str_ins_ch( str, 0, L' ' );
     va.set( sv.pos(), str );
     }
   if ( SEEDCOL > opt->xmax || SEEDCOL < 1 )
@@ -1425,24 +1436,24 @@
 
 /*--------------------------------------------------------------------*/
 
-  void SeeEditor::kinsert( int ch )
+  void SeeEditor::kinsert( wchar_t wch )
   {
-  if ( ch < 0 || ch > 255 ) return;
-  if ( ch == 13 || ch == 10 )
+  if ( UKEY_IS_WIDE_CTRL( wch ) ) return;
+  if ( wch == 13 || wch == 10 )
     {
     kenter();
     return;
     }
   mod = 1;
-  if ( va.count() == 0 ) va.push( "" );
-  VString str = va[sv.pos()];
+  if ( va.count() == 0 ) va.push( L"" );
+  WString str = va[sv.pos()];
 
   int c = real_col();
 
   if (!opt->insert)
     str_del( str, c, 1 );
-  if ( str_len(str) < c ) str_pad( str, -c, ' ' );
-  str_ins_ch( str, c, ch );
+  if ( str_len(str) < c ) str_pad( str, -c, L' ' );
+  str_ins_ch( str, c, wch );
   va.set( sv.pos(), str );
   right();
 
@@ -1458,7 +1469,7 @@
 
 /*--------------------------------------------------------------------*/
 
-  void SeeEditor::insert_file( const char* fn )
+  void SeeEditor::insert_file( const char* fn __attribute__((unused)) )
   {
   mod = va.count();
 
@@ -1479,7 +1490,7 @@
   if ( n == sv.max() )
     {
     if ( str_len( va[n] ) == 0 ) return;
-    va.set( n, "" );
+    va.set( n, L"" );
     }
   else
     {
@@ -1509,15 +1520,15 @@
     {
     ASSERT( sv.max() == va.count() - 1 );
     if ( n < 0 || n > sv.max() ) return;
-    VString str = va[n];
-    str_cut_right( str, " \t\n\r" );
+    WString str = va[n];
+    str_cut_right( str, L" \t\n\r" );
     va.set( n, str );
     }
   else
   for ( int z = 0; z < va.count(); z++ )
     {
-    VString str = va[z];
-    str_cut_right( str, " \t\n\r" );
+    WString str = va[z];
+    str_cut_right( str, L" \t\n\r" );
     va.set( z, str );
     }
   }
@@ -1529,12 +1540,13 @@
   VString sss = "Command to pipe in: ";
   int ii = str_len( sss )+2;
   status( sss );
-  sss = opt->last_pipe_cmd;
-  if(!TextInput( opt->xmin+ii, opt->ymax, "", opt->xmax-ii-4, opt->xmax-ii-4, &sss ))
+  WString www = opt->last_pipe_cmd;
+  if( ! TextInput( opt->xmin+ii, opt->ymax, "", opt->xmax-ii-4, opt->xmax-ii-4, www ) )
     {
     draw();
     return;
     }
+  sss = www;  
   str_sleft( sss, MAX_SEARCH_LEN );
   strcpy( opt->last_pipe_cmd, sss );
   FILE* f = popen( opt->last_pipe_cmd, "r" );
@@ -1567,12 +1579,12 @@
   int pos = -1;
   for ( z = sv.pos() + 1; z <= sv.max(); z++ )
     {
-    VString str = va[z];
+    WString str = va[z];
     if ( opt->no_case )
       str_up( str );
     if ( opt->last_search[0] == '~' )
       pos = str_find_regexp( str, opt->last_search + 1 );
-    else if ( str[0] == '\\' )
+    else if ( str[0] == L'\\' )
       pos = str_find( str, opt->last_search + 1 );
     else
       pos = str_find( str, opt->last_search );
@@ -1602,17 +1614,15 @@
 
   int SeeEditor::find( int no_case )
   {
-  VString sss;
   status( "Find %s: ", no_case?"(no case)":"(case sense)" );
-  int ii = str_len(sss)+2;
-  sss = opt->last_search;
-  if(!TextInput( opt->xmin+ii, opt->ymax, "", opt->xmax-ii-4, opt->xmax-ii-4, &sss ))
+  WString www = opt->last_search;
+  if( ! TextInput( opt->xmin, opt->ymax, "", opt->xmax-1, opt->xmax-1, www ) )
     {
     draw();
     return 1;
     }
-  str_sleft( sss, MAX_SEARCH_LEN );
-  strcpy( opt->last_search, sss );
+  str_sleft( www, MAX_SEARCH_LEN );
+  VS_FN_STRCPY( opt->last_search, www );
   opt->no_case = no_case;
   if ( opt->no_case )
     str_up( opt->last_search );
@@ -1623,9 +1633,9 @@
 
   void SeeEditor::help()
   {
-  con_out( 1, 1, help_str );
+  vfu_con_out( 1, 1, help_str );
   do_draw = 1;
-  con_getch();
+  con_getwch();
   }
 
 /*--------------------------------------------------------------------*/
@@ -1636,7 +1646,7 @@
   draw();
   set_cursor();
 
-  int key;
+  wchar_t wch;
   int pend = 0; /* used for double key-strokes as ^K^x command */
   while(4)
     {
@@ -1647,93 +1657,90 @@
     int oi  = opt->insert;
 
     pend = 0;
-    key = con_getch();
-    if( key == 0 ) key = KEY_CTRL_L;
-    if (key == KEY_CTRL_C)
+    wch = con_getwch();
+    if( wch == 0 ) wch = UKEY_CTRL_L;
+    if ( wch == UKEY_CTRL_C )
       {
       mod = 0; /* it is `quit' i.e. no save so this should be ok */
-      return key;
+      return wch;
       }
-    if (key == KEY_CTRL_X)
+    if ( wch == UKEY_CTRL_X )
       {
         save();
-        return key;
+        return wch;
       } else
-    if ( key == 27 || key == KEY_ALT_X )
+    if ( wch == 27 || wch == UKEY_ALT_X )
       {
       if ( request_quit() == 0 )
-        return key;
+        return wch;
       else
         continue;
       }
-    if ( key == KEY_CTRL_K )
+    if ( wch == UKEY_CTRL_K )
       {
-      pend = key;
-      con_out( SEEDCOL, SEEDROW, "^K", opt->cs );
+      pend = wch;
+      vfu_con_out( SEEDCOL, SEEDROW, "^K", opt->cs );
       set_cursor();
-      key = con_getch();
+      wch = con_getwch();
       draw_line( sv.pos() );
       }
 
-    switch( key )
+    switch( wch )
       {
-      case KEY_CTRL_N :
-      case KEY_DOWN   : down(); break;
-      case KEY_CTRL_P :
-      case KEY_UP     : up(); break;
-      case KEY_CTRL_B :
-      case KEY_LEFT   : left(); break;
-      case KEY_CTRL_F :
-      case KEY_RIGHT  : right(); break;
-      case KEY_CTRL_U : if ( pend == KEY_CTRL_K )
+      case UKEY_CTRL_N :
+      case UKEY_DOWN   : down(); break;
+      case UKEY_CTRL_P :
+      case UKEY_UP     : up(); break;
+      case UKEY_CTRL_B :
+      case UKEY_LEFT   : left(); break;
+      case UKEY_CTRL_F :
+      case UKEY_RIGHT  : right(); break;
+      case UKEY_CTRL_U : if ( pend == UKEY_CTRL_K )
                           sv.home();
                         else
                           sv.ppage();
                         break;
-      case KEY_PPAGE  : sv.ppage(); break;
-      case KEY_CTRL_V : if ( pend == KEY_CTRL_K )
+      case UKEY_PGUP  : sv.ppage(); break;
+      case UKEY_CTRL_V : if ( pend == UKEY_CTRL_K )
                           sv.end();
                         else
                           sv.npage();
                         break;
-      case KEY_NPAGE  : sv.npage(); break;
-      case KEY_CTRL_A :
-      case KEY_HOME   : home(); break;
-      case KEY_CTRL_E :
-      case KEY_END    : end();  break;
-      case KEY_INSERT : opt->insert = !opt->insert; break;
+      case UKEY_PGDN  : sv.npage(); break;
+      case UKEY_CTRL_A :
+      case UKEY_HOME   : home(); break;
+      case UKEY_CTRL_E :
+      case UKEY_END    : end();  break;
+      case UKEY_INS    : opt->insert = !opt->insert; break;
 
-      case KEY_CTRL_Y : remove_line(); break;
+      case UKEY_CTRL_Y : remove_line(); break;
 
       /* SeedKxxx functions are for KEYxxx handles */
-      case KEY_ALT_H  :
-      case KEY_F1     : help(); break;
+      case UKEY_ALT_H  :
+      case UKEY_F1     : help(); break;
 
-      case KEY_CTRL_S :
-      case KEY_F2     : save(); break;
-      case KEY_CTRL_D : if ( pend == KEY_CTRL_K )
+      case UKEY_CTRL_S :
+      case UKEY_F2     : save(); break;
+      case UKEY_CTRL_D : if ( pend == UKEY_CTRL_K )
                           save();
                         else
                           kdel();
                         break;
 
-      case KEY_ALT_F     : find( 1 ); break;
-      case KEY_ALT_S     : find( 0 ); break;
+      case UKEY_ALT_F     : find( 1 ); break;
+      case UKEY_ALT_S     : find( 0 ); break;
 
-      case KEY_ALT_G     :
-      case KEY_F3        : find_next(); break;
+      case UKEY_ALT_G     :
+      case UKEY_F3        : find_next(); break;
 
-      case KEY_DEL       : kdel(); break;
+      case UKEY_DEL       : kdel(); break;
 
-      #ifndef _TARGET_GO32_
-      case KEY_BACKSPACE :
-      #endif
-      case KEY_CTRL_H    : kbs(); break;
+      case UKEY_CTRL_H    : kbs(); break;
 
       case 10            :
       case 13            : kenter(); break;
 
-      case KEY_CTRL_L    : if ( opt->auto_size )
+      case UKEY_CTRL_L    : if ( opt->auto_size )
                               {
                               opt->xmin = 1;
                               opt->ymin = 1;
@@ -1746,25 +1753,25 @@
                            con_cs();
                            draw();
                            break;
-      case KEY_CTRL_W    : insert_pipe_cmd(); break;
+      case UKEY_CTRL_W    : insert_pipe_cmd(); break;
 
-      case KEY_CTRL_T    : opt->auto_indent = !opt->auto_indent;
+      case UKEY_CTRL_T    : opt->auto_indent = !opt->auto_indent;
                            status( (opt->auto_indent) ? "AutoIndent ON" : "AutoIndent OFF" );
                            break;
 
-      case KEY_ALT_0  :
-      case KEY_ALT_1  :
-      case KEY_ALT_2  :
-      case KEY_ALT_3  :
-      case KEY_ALT_4  :
-      case KEY_ALT_5  :
-      case KEY_ALT_6  :
-      case KEY_ALT_7  :
-      case KEY_ALT_8  :
-      case KEY_ALT_9  : if (key == KEY_ALT_0) key = KEY_ALT_9+1;
-                        return key;
-      case 27         : return key;
-      default         : kinsert( key ); break;
+      case UKEY_ALT_0  :
+      case UKEY_ALT_1  :
+      case UKEY_ALT_2  :
+      case UKEY_ALT_3  :
+      case UKEY_ALT_4  :
+      case UKEY_ALT_5  :
+      case UKEY_ALT_6  :
+      case UKEY_ALT_7  :
+      case UKEY_ALT_8  :
+      case UKEY_ALT_9  : if ( wch == UKEY_ALT_0 ) wch = UKEY_ALT_9+1;
+                        return wch;
+      case 27         : return wch;
+      default         : kinsert( wch ); break;
 
       }
 
