@@ -1,16 +1,20 @@
 /****************************************************************************
- *
- * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
- *
- * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
- *
+ #
+ # Copyright (c) 1996-2023 Vladi Belperchinov-Shabanski "Cade" 
+ # https://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
+ # https://cade.noxrun.com/projects/vfu     https://github.com/cade-vs/vfu
+ #
+ # SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
+ #
  ****************************************************************************/
 
 #ifndef _SEE_H_
 #define _SEE_H_
 
+#include <vstring.h>
+#include <wstring.h>
 #include <vslib.h>
+#include "vfuuti.h"
 
 #define SEE_VERSION "4.10"
 
@@ -169,8 +173,7 @@ class SeeViewer
 
 struct SeeEditorOptions
 {
-  SeeEditorOptions()
-    { reset(); }
+  SeeEditorOptions() { reset(); }
   void reset()
     {
     auto_size = 1;
@@ -206,7 +209,7 @@ struct SeeEditorOptions
   int auto_indent;
   int insert; /* if editor is in `insert' mode */
 
-  char last_search[MAX_SEARCH_LEN+1];
+  wchar_t last_search[MAX_SEARCH_LEN+1];
   int no_case;
   char last_pipe_cmd[MAX_PIPE_LEN];
 };
@@ -223,7 +226,7 @@ class SeeEditor
   int col;
   int colpage;
   ScrollPos sv; /* vertical scroller */
-  VArray va; /* string/text cluster */
+  WArray va; /* string/text cluster */
   int mod; /* modify flag */
 
   int rows;
@@ -273,7 +276,7 @@ class SeeEditor
   void kdel();
   void kbs();
   void kenter();
-  void kinsert( int ch );
+  void kinsert( wchar_t wch );
 
   void insert_file( const char* fn );
 
