@@ -363,7 +363,8 @@ void TF::refresh_view()
       {
       time_t ftm = vfu_opt_time( _st );
       time_str_compact( ftm, sttime );
-      strcat( sttime, ( time( NULL ) - ftm ) > 24*60*60 ? " " : "*" ); // TODO: use for something useful
+      long int tdiff = time( NULL ) - ftm;
+      strcat( sttime, tdiff > 0 ? tdiff > 23*60*60 ? " " : "*" : "!" ); // TODO: use for something useful
       strcat( sttime, " " ); /* field separator */
       }
 
@@ -425,7 +426,7 @@ void TF::update_stat( const struct stat* a_new_stat, int a_is_link )
     stat( _name, &_st );
 
   _is_link = (a_is_link == -1) ? file_is_link( _name ) : a_is_link;
-  _is_dir = S_ISDIR(_st.st_mode );
+  _is_dir  = S_ISDIR(_st.st_mode );
   strcpy( _type_str, file_type_str( _st.st_mode, _is_link ) );
 
   file_get_mode_str( _st.st_mode, _mode_str );
@@ -510,6 +511,8 @@ void vfu_help()
   mb.push( L"V       -- edit vfu.conf file");
   mb.push( L"!       -- shell (also available with '?')"                         );
   mb.push( L"/       -- command line"                                            );
+  mb.push( L"`       -- bookmarks menu"                                          );
+  mb.push( L"Alt+#   -- where # is 1..9, go to #'th bookmark"                    );
   mb.push( L"vfu uses these (one of) these config files:");
   mb.push( L"        1. $HOME/$RC_PREFIX/vfu/vfu.conf");
   mb.push( L"        2. $HOME/.vfu/vfu.conf");
@@ -800,6 +803,16 @@ void vfu_run()
       case L'+' :
       case L'=' : vfu_action_plus( wch ); break;
 
+      case L'[' : vfu_action_minus();
+                  vfu_nav_up();
+                  vfu_action_plus( 13 );
+                  break;
+
+      case L']' : vfu_action_minus();
+                  vfu_nav_down();
+                  vfu_action_plus( 13 );
+                  break;
+
       case UKEY_LEFT  : if (opt.lynx_navigation) vfu_action_minus(); break;
       case UKEY_RIGHT : if (opt.lynx_navigation)
                          vfu_action_plus( L'+' );
@@ -1910,37 +1923,8 @@ void vfu_tools()
   mb.push( L"C Classify files" );
   if ( vfu_menu_box( 30, 5, L"Tools" ) == -1 ) return;
 
-  TF *fi = FLCUR;
-
   switch( menu_box_info.ec )
     {
-    case L'R' : {
-               say1( expand_path( fi->name() ) );
-               break;
-               }
-    case L'D' : {
-               if( ! fi->is_link() ) break;
-               tools_last_target = fi->full_name();
-               if( ! fi->is_dir() ) break;
-               vfu_chdir( expand_path( fi->name() ) );
-               break;
-               }
-    case L'G' : {
-               if( ! fi->is_link() ) break;
-               tools_last_target = fi->full_name();
-               VString target = vfu_readlink( fi->full_name() );
-               vfu_chdir( expand_path( str_file_path( target ) ) );
-               vfu_goto_filename( str_file_name_ext( target ) );
-               break;
-               }
-    case L'B' : {
-               if( tools_last_target == "" ) break;
-               VString target = tools_last_target;
-               tools_last_target = fi->full_name();
-               vfu_chdir( expand_path( str_file_path( target ) ) );
-               vfu_goto_filename( str_file_name_ext( target ) );
-               break;
-               }
     case L'T' : {
                VString str;
                if (vfu_get_str( "Make directory(ies) (use space for separator)", str, HID_MKPATH ))
@@ -1958,13 +1942,52 @@ void vfu_tools()
                      err++;
                      }
                  if ( err == 0 ) say1( "MKDIR: ok." );
-                 break;
+                 return;
                  }
                }
-               break;
-    case L'P' : bookmark_goto( 0 ); break;
-    case L'A' : vfu_tool_rename(); break;
-    case L'C' : vfu_tool_classify(); break;
+               return;
+    case L'P' : bookmark_goto( 0 );  return;
+    }
+
+  if( files_list_count() < 1 )
+    {
+    say1( "No files..." );
+    return;
+    }
+  
+  TF *fi = FLCUR;
+
+  switch( menu_box_info.ec )
+    {
+    case L'R' : {
+               say1( expand_path( fi->name() ) );
+               return;
+               }
+    case L'D' : {
+               if( ! fi->is_link() ) return;
+               tools_last_target = fi->full_name();
+               if( ! fi->is_dir() ) return;
+               vfu_chdir( expand_path( fi->name() ) );
+               return;
+               }
+    case L'G' : {
+               if( ! fi->is_link() ) return;
+               tools_last_target = fi->full_name();
+               VString target = vfu_readlink( fi->full_name() );
+               vfu_chdir( expand_path( str_file_path( target ) ) );
+               vfu_goto_filename( str_file_name_ext( target ) );
+               return;
+               }
+    case L'B' : {
+               if( tools_last_target == "" ) return;
+               VString target = tools_last_target;
+               tools_last_target = fi->full_name();
+               vfu_chdir( expand_path( str_file_path( target ) ) );
+               vfu_goto_filename( str_file_name_ext( target ) );
+               return;
+               }
+    case L'A' : vfu_tool_rename();   return;
+    case L'C' : vfu_tool_classify(); return;
     }
 }
 
@@ -2863,12 +2886,12 @@ void vfu_inc_search( int use_last_one )
   VString no_case_opt_str = opt.no_case_glob ? " no-case " : " ";
   if( use_last_one )
     {
-    say1( "Incremental" + no_case_opt_str + "search pattern: ( ALT+S for next match )" );
+    say1( "Incremental" + no_case_opt_str + "search: ( ALT+S for next match )" );
     wch = 9;
     }
   else
     {
-    say1( "Enter incremental" + no_case_opt_str + "search pattern: ( TAB for next match or 'size:NNN' for size search )" );
+    say1( "Incremental" + no_case_opt_str + "search: ( TAB for next or 'size:NNN' search )" );
     wch = con_getwch();
     }
   WRegexp size_re( L"^size:\\s*(\\d+)$" ); // TODO: allow "size:1024+"
