@@ -1,10 +1,11 @@
 /****************************************************************************
- *
- * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.datamax.bg/  <cade@biscom.net> <cade@bis.bg> <cade@datamax.bg>
- *
- * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
- *
+ #
+ # Copyright (c) 1996-2023 Vladi Belperchinov-Shabanski "Cade" 
+ # https://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
+ # https://cade.noxrun.com/projects/vfu     https://github.com/cade-vs/vfu
+ #
+ # SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
+ #
  ****************************************************************************/
 
 #include "vfu.h"
@@ -16,64 +17,62 @@
 
 Options opt;
 
-const char *NOYES[] = { " - ", "YES", NULL };
-const char *NOYESPRECOPY[] = { " - ", "YES", "PRELIM", NULL };
-const char *FTIMETYPE[] = { "CHANGE", "MODIFY", "ACCESS", NULL };
-#ifdef _TARGET_GO32_
-const char *TAGMARKS[] = { ">>", "=>", "->", "", "", " ", "", NULL };
-#else
-const char *TAGMARKS[] = { ">>", "=>", "->", NULL };
-#endif
-const char *SIIEC[] = { "IEC", "SI ", NULL };
-const char *COMMA_TYPES[] = { "'", "`", ",", " ", "_", NULL };
+const wchar_t *NOYES[]        = { L" - ", L"YES", NULL };
+const wchar_t *NOYESPRECOPY[] = { L" - ", L"YES", L"PRELIM", NULL };
+const wchar_t *FTIMETYPE[]    = { L"CHANGE", L"MODIFY", L"ACCESS", NULL };
+const wchar_t *TAGMARKS[]     = { L">>", L"=>", L"->", L"*>", NULL };
+const wchar_t *SIIEC[]        = { L"IEC", L"SI ", NULL };
+const wchar_t *COMMA_TYPES[]  = { L"'", L"`", L",", L" ", L"_", NULL };
+const wchar_t *PAGE_STEPS[]   = { L"1 LINE", L"30% PG", L"50% PG", NULL };
 
 ToggleEntry Toggles[] =
 {
 //  { "[a] 1234567890123456", &(opt.some) },
-  {  0 , "--screen--", NULL, NULL },
-  { '1', "Show Mode  field", &(opt.f_mode), NOYES },
-  { '2', "Show Owner field", &(opt.f_owner), NOYES },
-  { '3', "Show Group field", &(opt.f_group), NOYES },
-  { '4', "Show Time  field", &(opt.f_time), NOYES },
-  { '5', "Show Size  field", &(opt.f_size), NOYES },
-  { '6', "Show Type  field", &(opt.f_type), NOYES },
-  { '7', "     Time Type ", &(opt.f_time_type), FTIMETYPE },
-  { '8', "Long name view ", &(opt.long_name_view), NOYES },
-  { ' ', "TagMark type   ", &(opt.tag_mark_type), TAGMARKS },
-  { ' ', "Use colors     ", &(opt.use_colors), NOYES },
-  { ' ', "Use /etc/DIR_COLORS", &(opt.use_dir_colors), NOYES },
-  { ' ', "Lowercase extensions for configs", &(opt.lower_case_ext_config), NOYES },
-  { '.', "Show hidden files", &(opt.show_hidden_files), NOYES },
-  {  0 , "--navigation--", NULL, NULL },
-  { 'i', "Use internal viewer", &(opt.internal_browser), NOYES },
-  { 'I', "Use internal editor", &(opt.internal_editor), NOYES },
-  { ' ', "Use menu borders", &(opt.menu_borders), NOYES },
-  {  0 , "--trees/dirs-- " , NULL, NULL },
-  { ' ', "Compact DirTree", &(opt.tree_compact), NOYES },
-  { ' ', "CDTree (cdpath) ", &(opt.tree_cd), NOYES },
-  {  0 , "--troubleshooting--", NULL, NULL },
-  { ' ', "Clear screen on shell", &(opt.shell_cls), NOYES },
-  {  0 , "--compatibility--", NULL, NULL },
-  { ' ', "Lynx style navigation",       &(opt.lynx_navigation), NOYES },
-  { ' ', "Mask auto expand", &(opt.mask_auto_expand), NOYES },
-  { ' ', "Use CWD as target for COPY/MOVE", &(opt.default_copy_to_cwd), NOYES },
-  {  0 , "--other--", NULL, NULL },
-/*  { ' ', "Can Zap/Erase READ-ONLY Files?!",       &(opt.zap_ro), NOYES }, ? */
-  { ' ', "Keep directories on top of the list",    &(opt.sort_top_dirs), NOYES },
-  { ' ', "Smart HOME/END keys (only Top Dirs mode)",    &(opt.smart_home_end), NOYES },
-  { ' ', "Case insensitive file/dir names matching",       &(opt.no_case_glob), NOYES },
-  { 'b', "Allow beep!",       &(opt.allow_beep), NOYES },
-  { 's', "Free space check on copy",  &(opt.copy_free_space_check), NOYES },
-  { ' ', "Auto mount on change dir",  &(opt.auto_mount), NOYES},
-  { ' ', "Preserve selection (after rescan)",  &(opt.keep_selection), NOYES},
-  { ' ', "Preserve ownership/mode on copy?", &(opt.copy_keep_mode), NOYES },
-  { ' ', "Show user's free space", &(opt.show_user_free), NOYES },
-  { ' ', "Calc/Show bytes on copy", &(opt.copy_calc_totals), NOYESPRECOPY },
-  { ' ', "Calc/Show bytes freed on erase", &(opt.bytes_freed), NOYES },
-  { ' ', "Prefer GiB in disk usage status", &(opt.use_gib_usage), NOYES },
-  { ' ', "Show file/dir sizes in units", &(opt.use_si_sizes), SIIEC },
-  { ' ', "1000s separator type", &(opt.comma_type), COMMA_TYPES },
-  {  -1, "---", NULL, NULL }
+  { L' ', L"--screen--", NULL, NULL },
+  { L'1', L"Show Mode  field", &(opt.f_mode), NOYES },
+  { L'2', L"Show Owner field", &(opt.f_owner), NOYES },
+  { L'3', L"Show Group field", &(opt.f_group), NOYES },
+  { L'4', L"Show Time  field", &(opt.f_time), NOYES },
+  { L'5', L"Show Size  field", &(opt.f_size), NOYES },
+  { L'6', L"Show Type  field", &(opt.f_type), NOYES },
+  { L'7', L"     Time Type ", &(opt.f_time_type), FTIMETYPE },
+  { L'8', L"Long name view ", &(opt.long_name_view), NOYES },
+  { L' ', L"TagMark type   ", &(opt.tag_mark_type), TAGMARKS },
+  { L' ', L"Use colors     ", &(opt.use_colors), NOYES },
+  { L' ', L"Use /etc/DIR_COLORS", &(opt.use_dir_colors), NOYES },
+  { L' ', L"Lowercase extensions for configs", &(opt.lower_case_ext_config), NOYES },
+  { L'.', L"Show hidden files", &(opt.show_hidden_files), NOYES },
+  { L' ', L"--navigation--", NULL, NULL },
+  { L'i', L"Use internal viewer", &(opt.internal_browser), NOYES },
+  { L'I', L"Use internal editor", &(opt.internal_editor), NOYES },
+  { L' ', L"Use menu borders", &(opt.menu_borders), NOYES },
+  { L' ', L"--trees/dirs-- " , NULL, NULL },
+  { L' ', L"Compact DirTree", &(opt.tree_compact), NOYES },
+  { L' ', L"CDTree (cdpath) ", &(opt.tree_cd), NOYES },
+  { L' ', L"--troubleshooting--", NULL, NULL },
+  { L' ', L"Clear screen on shell", &(opt.shell_cls), NOYES },
+  { L' ', L"--compatibility--", NULL, NULL },
+  { L' ', L"Lynx style navigation",       &(opt.lynx_navigation), NOYES },
+  { L' ', L"Mask auto expand", &(opt.mask_auto_expand), NOYES },
+  { L' ', L"Use CWD as target for COPY/MOVE", &(opt.default_copy_to_cwd), NOYES },
+  { L' ', L"--other--", NULL, NULL },
+/*  { ' 'L, "Can Zap/Erase READ-ONLY Files?!",       &(opt.zap_ro), NOYES }, ? */
+  { L' ', L"Keep directories on top of the list",    &(opt.sort_top_dirs), NOYES },
+  { L' ', L"Smart HOME/END keys (only Top Dirs mode)",    &(opt.smart_home_end), NOYES },
+  { L' ', L"Case insensitive file/dir names matching",       &(opt.no_case_glob), NOYES },
+  { L'b', L"Allow beep!",       &(opt.allow_beep), NOYES },
+  { L's', L"Free space check on copy",  &(opt.copy_free_space_check), NOYES },
+  { L' ', L"Auto mount on change dir",  &(opt.auto_mount), NOYES},
+  { L' ', L"Preserve selection (after rescan)",  &(opt.keep_selection), NOYES},
+  { L' ', L"Preserve ownership/mode on copy?", &(opt.copy_keep_mode), NOYES },
+  { L' ', L"Show user's free space", &(opt.show_user_free), NOYES },
+  { L' ', L"Calc/Show bytes on copy", &(opt.copy_calc_totals), NOYESPRECOPY },
+  { L' ', L"Calc/Show bytes freed on erase", &(opt.bytes_freed), NOYES },
+  { L' ', L"Prefer GiB in disk usage status", &(opt.use_gib_usage), NOYES },
+  { L' ', L"Show file/dir sizes in units", &(opt.use_si_sizes), SIIEC },
+  { L' ', L"1000s separator type", &(opt.comma_type), COMMA_TYPES },
+  { L' ', L"Scrolling page step", &(opt.scroll_pagestep), PAGE_STEPS },
+  {    0, L"---", NULL, NULL }
 };
 
 /*---------------------------------------------------------------------------*/
@@ -207,11 +206,11 @@ int set_splitter( const char *line, const char *keyword, VArray &splitter )
 
 int key_by_name( const char* key_name )
 {
-  if ( strcmp( key_name, "IC"     ) == 0 ) return KEY_IC;
-  if ( strcmp( key_name, "INS"    ) == 0 ) return KEY_IC;
-  if ( strcmp( key_name, "INSERT" ) == 0 ) return KEY_IC;
-  if ( strcmp( key_name, "ENTER"  ) == 0 ) return KEY_ENTER;
-  if ( strcmp( key_name, "RETURN" ) == 0 ) return KEY_ENTER;
+  if ( strcmp( key_name, "IC"     ) == 0 ) return UKEY_INS;
+  if ( strcmp( key_name, "INS"    ) == 0 ) return UKEY_INS;
+  if ( strcmp( key_name, "INSERT" ) == 0 ) return UKEY_INS;
+  if ( strcmp( key_name, "ENTER"  ) == 0 ) return UKEY_ENTER;
+  if ( strcmp( key_name, "RETURN" ) == 0 ) return UKEY_ENTER;
   /*
   if (strcmp (key_name, "MENU"  ) == 0) ux.key = - menucount;
   */
@@ -220,20 +219,20 @@ int key_by_name( const char* key_name )
   if ( reFKEYS.m( key_name ) )
     {
     if ( toupper(key_name[0]) == 'F' )
-      return KEY_F1 + atoi( key_name + 1 ) - 1; else
+      return UKEY_F1 + atoi( key_name + 1 ) - 1; else
     if ( toupper(key_name[0]) == '@' )
-      return KEY_ALT_F1 + atoi( key_name + 2 ) - 1; else
+      return UKEY_ALT_F1 + atoi( key_name + 2 ) - 1; else
     if ( toupper(key_name[0]) == '^' )
-      return KEY_CTRL_F1 + atoi( key_name + 2 ) - 1; else
+      return UKEY_CTRL_F1 + atoi( key_name + 2 ) - 1; else
     if ( toupper(key_name[0]) == '#' )
-      return KEY_SH_F1 + atoi( key_name + 2 ) - 1;
+      return UKEY_SH_F1 + atoi( key_name + 2 ) - 1;
     }
   return 0;
 }
 
 /*---------------------------------------------------------------------------*/
 
-void vfu_settings_load()
+void vfu_settings_load( VArray* data = NULL )
 {
   VString str;
 
@@ -246,10 +245,7 @@ void vfu_settings_load()
 
   /***** LOAD DEFAULTS *******/
 
-  memset( &opt, 0, sizeof( opt ) );
-
-  opt.svo.reset();
-  opt.seo.reset();
+  opt.reset();
   opt.seo.handle_tab = 1;
 
   opt.sort_order = 'N';
@@ -304,18 +300,18 @@ void vfu_settings_load()
 
   opt.smart_home_end = 1;
 
+  opt.scroll_pagestep = 1;
   /***** LOAD DEFAULTS END ***/
 
-  FILE *fsett;
-
   Options tmp_opt;
-  memset( &tmp_opt, 0, sizeof( tmp_opt ) );
+  tmp_opt.reset();
   if ( file_load_crc32( filename_opt, &tmp_opt, sizeof( tmp_opt ) ) == 0 )
     memcpy( &opt, &tmp_opt, sizeof(Options) );
   else
     say1( "warning: bad vfu.options file, loading defaults..." );
 
   history.fload( filename_history );
+  file_list_index.set_pagestep( OPT_SCROLL_PAGESTEP(opt.scroll_pagestep) );
 
   if ( getenv("EDITOR"))
     {
@@ -342,84 +338,78 @@ void vfu_settings_load()
   VRegexp re_see( "^\\s*see\\s*=\\s*([^, \011]*)\\s*,(.*)$", "i" );
   VRegexp re_pan( "^\\s*panelize\\s*=\\s*([^,]*)\\s*,(.*)$", "i" );
 
-  char line[1024];
-  if ( (fsett = fopen( filename_conf, "r")) )
+  VArray conf_data;
+  
+  if ( data ) 
+    conf_data = *data;
+  else
+    conf_data.fload( filename_conf );  
+
+  for( int c = 0; c < conf_data.count(); c++ )
     {
-    while(fgets(line, 1024, fsett))
+    const char* line = conf_data.get( c );
+    if ( line[0] == '#' ) continue;
+    if ( line[0] == ';' ) continue;
+    if ( strlen( line ) == 0 ) continue;
+
+    if(set_str( line, "browser", shell_browser))continue;
+    if(set_str( line, "pager", shell_browser))continue;
+    if(set_str( line, "viewer", shell_browser))continue;
+
+    if(set_arr( line, "archive",  archive_extensions))continue;
+
+    if(set_str( line, "editor", shell_editor))continue;
+    if(set_str( line, "diff",   shell_diff))continue;
+
+    if(set_arr( line, "bookmark",  path_bookmarks))continue;
+
+ /* if(set_str( line, "cblack"   , ext_colors[0]); */
+    if(set_str( line, "cgreen"   , ext_colors[cGREEN]))continue;
+    if(set_str( line, "cred"     , ext_colors[cRED]))continue;
+    if(set_str( line, "ccyan"    , ext_colors[cCYAN]))continue;
+    if(set_str( line, "cwhite"   , ext_colors[cWHITE]))continue;
+    if(set_str( line, "cmagenta" , ext_colors[cMAGENTA]))continue;
+    if(set_str( line, "cblue"    , ext_colors[cBLUE]))continue;
+    if(set_str( line, "cyellow"  , ext_colors[cYELLOW]))continue;
+    if(set_str( line, "chblack"  , ext_colors[chBLACK]))continue;
+    if(set_str( line, "chgreen"  , ext_colors[chGREEN]))continue;
+    if(set_str( line, "chred"    , ext_colors[chRED]))continue;
+    if(set_str( line, "chcyan"   , ext_colors[chCYAN]))continue;
+    if(set_str( line, "chwhite"  , ext_colors[chWHITE]))continue;
+    if(set_str( line, "chmagenta", ext_colors[chMAGENTA]))continue;
+    if(set_str( line, "chblue"   , ext_colors[chBLUE]))continue;
+    if(set_str( line, "chyellow" , ext_colors[chYELLOW]))continue;
+
+    if(set_splitter( line, "trimtree",  trim_tree  ))continue;
+
+    /* following code is used to clean input data */
+    if( re_ux.m( line ) )
       {
-      if ( line[0] == '#' ) continue;
-      if ( line[0] == ';' ) continue;
-      str_cut( line, "\n\r" );
-      if ( strlen( line ) == 0 ) continue;
-
-      if(set_str( line, "browser", shell_browser))continue;
-      if(set_str( line, "pager", shell_browser))continue;
-      if(set_str( line, "viewer", shell_browser))continue;
-
-      if(set_arr( line, "archive",  archive_extensions))continue;
-
-      if(set_str( line, "editor", shell_editor))continue;
-      if(set_str( line, "diff",   shell_diff))continue;
-
-      if(set_arr( line, "bookmark",  path_bookmarks))continue;
-
-   /* if(set_str( line, "cblack"   , ext_colors[0]); */
-      if(set_str( line, "cgreen"   , ext_colors[cGREEN]))continue;
-      if(set_str( line, "cred"     , ext_colors[cRED]))continue;
-      if(set_str( line, "ccyan"    , ext_colors[cCYAN]))continue;
-      if(set_str( line, "cwhite"   , ext_colors[cWHITE]))continue;
-      if(set_str( line, "cmagenta" , ext_colors[cMAGENTA]))continue;
-      if(set_str( line, "cblue"    , ext_colors[cBLUE]))continue;
-      if(set_str( line, "cyellow"  , ext_colors[cYELLOW]))continue;
-      if(set_str( line, "chblack"  , ext_colors[chBLACK]))continue;
-      if(set_str( line, "chgreen"  , ext_colors[chGREEN]))continue;
-      if(set_str( line, "chred"    , ext_colors[chRED]))continue;
-      if(set_str( line, "chcyan"   , ext_colors[chCYAN]))continue;
-      if(set_str( line, "chwhite"  , ext_colors[chWHITE]))continue;
-      if(set_str( line, "chmagenta", ext_colors[chMAGENTA]))continue;
-      if(set_str( line, "chblue"   , ext_colors[chBLUE]))continue;
-      if(set_str( line, "chyellow" , ext_colors[chYELLOW]))continue;
-
-      if(set_splitter( line, "trimtree",  trim_tree  ))continue;
-
-      /* following code is used to clean input data */
-      if( re_ux.m( line ) )
-        {
-        str = "";
-        str = str + re_ux[1] + ","; /* get description */
-        str = str + re_ux[2] + ","; /* get key name */
-        VString t = re_ux[3]; /* get extensions */
-        if ( t != "*" && t[-1] != '.' ) t += ".";
-        str = str + t + ",";
-        str += re_ux[4]; /* get shell line */
-        user_externals.push( str );
-        continue;
-        } else
-      if( re_see.m( line ) )
-        {
-        str = "";
-        see_filters.push( str + re_see[1] + "," + re_see[2] );
-        continue;
-        } else
-      if( re_pan.m( line ) )
-        {
-        str = "";
-        panelizers.push( str + re_pan[1] + "," + re_pan[2] );
-        continue;
-        }
+      str = "";
+      str = str + re_ux[1] + ","; /* get description */
+      str = str + re_ux[2] + ","; /* get key name */
+      VString t = re_ux[3]; /* get extensions */
+      if ( t != "*" && t[-1] != '.' ) t += ".";
+      str = str + t + ",";
+      str += re_ux[4]; /* get shell line */
+      user_externals.push( str );
+      continue;
+      } else
+    if( re_see.m( line ) )
+      {
+      str = "";
+      see_filters.push( str + re_see[1] + "," + re_see[2] );
+      continue;
+      } else
+    if( re_pan.m( line ) )
+      {
+      str = "";
+      panelizers.push( str + re_pan[1] + "," + re_pan[2] );
+      continue;
       }
-    fclose(fsett);
     }
 
-  #ifdef _TARGET_GO32_
-  int z;
-  for ( z = 0; z < 16; z++ ) str_low( ext_colors[z] );
-  #endif
-
   if (opt.use_dir_colors) vfu_load_dir_colors();
-//  if (file_load_crc32( filename_size_cache, &size_cache, sizeof(size_cache)))
-//    memset( &size_cache, 0, sizeof(size_cache) );
-  size_cache_load();
 }
 
 /*---------------------------------------------------------------------------*/
@@ -456,8 +446,8 @@ void vfu_edit_conf_file()
   else
     {
     VString line = shell_editor;
-    str_replace( line, "%f", filename_conf );
-    str_replace( line, "%F", filename_conf );
+    str_replace( line, "%f", shell_escape( filename_conf ) );
+    str_replace( line, "%F", shell_escape( filename_conf ) );
     vfu_shell( line.data(), 0 );
     }
   vfu_settings_save();
@@ -473,7 +463,7 @@ void vfu_options()
 {
   say1("press SPACE to toggle, ENTER or ESC to exit");
   say2("");
-  vfu_toggle_box( 30, 5, "Options/Toggles (scroll down, SPACE selects)", Toggles );
+  vfu_toggle_box( 30, 5, L"Options/Toggles (scroll down, SPACE selects)", Toggles );
   vfu_settings_save();
   vfu_settings_load();
   vfu_drop_all_views();
