@@ -1,10 +1,11 @@
 /****************************************************************************
- *
- * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
- *
- * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
- *
+ #
+ # Copyright (c) 1996-2023 Vladi Belperchinov-Shabanski "Cade" 
+ # https://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
+ # https://cade.noxrun.com/projects/vfu     https://github.com/cade-vs/vfu
+ #
+ # SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
+ #
  ****************************************************************************/
 
 #ifndef _VFUOPT_H_
@@ -13,14 +14,17 @@
 #include "see.h"
 #include "vfuuti.h"
 
-  extern const char *NOYES[];
-  extern const char *FTIMETYPE[];
-  extern const char *TAGMARKS[];
-  extern const char *COMMA_TYPES[];
+  #define OPT_SCROLL_PAGESTEP(s)  ( (s) == 1 ? 0.3 : (s) == 2 ? 0.5 : 1 )
+
+
+  extern const wchar_t *NOYES[];
+  extern const wchar_t *FTIMETYPE[];
+  extern const wchar_t *TAGMARKS[];
+  extern const wchar_t *COMMA_TYPES[];
 
   struct Options {
-    int sort_order;
-    int sort_direction;
+    wchar_t sort_order;
+    wchar_t sort_direction;
     int sort_top_dirs;
 
     fname_t last_copy_path[3];
@@ -81,9 +85,58 @@
     int use_gib_usage;
 
     int comma_type;
+
+    int scroll_pagestep;
     
     SeeViewerOptions svo;
     SeeEditorOptions seo;
+    void reset(void)
+    {
+      sort_order = 0;
+      sort_direction = 0;
+      sort_top_dirs = 0;
+      memset(last_copy_path, 0, sizeof last_copy_path);
+      memset(path_bookmarks, 0, sizeof path_bookmarks);
+      f_size = 0;
+      f_time = 0;
+      f_mode = 0;
+      f_group = 0;
+      f_owner = 0;
+      f_type = 0;
+      f_time_type = 0;
+      long_name_view = 0;
+      tree_compact = 0;
+      tree_cd = 0;
+      show_hidden_files = 0;
+      allow_beep = 0;
+      use_colors = 0;
+      use_dir_colors = 0;
+      lower_case_ext_config = 0;
+      copy_free_space_check = 0;
+      copy_calc_totals = 0;
+      copy_keep_mode = 0;
+      tag_mark_type = 0;
+      internal_browser = 0;
+      internal_editor = 0;
+      mask_auto_expand = 0;
+      shell_cls = 0;
+      zap_ro = 0;
+      no_case_glob = 0;
+      show_user_free = 0;
+      menu_borders = 0;
+      lynx_navigation = 0;
+      default_copy_to_cwd = 0;
+      auto_mount = 0;
+      keep_selection = 0;
+      bytes_freed = 0;
+      smart_home_end = 0;
+      use_si_sizes = 0;
+      use_gib_usage = 0;
+      comma_type = 0;
+      scroll_pagestep = 0;
+      svo.reset();
+      seo.reset();
+    }
   };
 
   extern Options opt;
@@ -99,7 +152,7 @@
   int set_set( const char *line, const char *keyword, int &target );
   int set_set( const char *line, const char *keyword, VArray &splitter );
 
-  void vfu_settings_load();
+  void vfu_settings_load( VArray* data );
   void vfu_settings_save();
 
   void vfu_edit_conf_file();
