@@ -1,10 +1,11 @@
 /****************************************************************************
- *
- * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
- *
- * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
- *
+ #
+ # Copyright (c) 1996-2023 Vladi Belperchinov-Shabanski "Cade" 
+ # https://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
+ # https://cade.noxrun.com/projects/vfu     https://github.com/cade-vs/vfu
+ #
+ # SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
+ #
  ****************************************************************************/
 
 #include "vfu.h"
@@ -12,10 +13,6 @@
 #include "vfuuti.h"
 #include "vfumenu.h"
 
-#ifdef _TARGET_GO32_
-  #include <io.h>
-#endif
-
 /*###########################################################################*/
 
 void file_get_mode_str( const mode_t tm, mode_str_t &mod_str )
@@ -38,15 +35,9 @@ void file_get_mode_str( const mode_t tm, mode_str_t &mod_str )
   if ((tm & S_IWOTH) != 0) mod_str[8] = 'w';
   if ((tm & S_IXOTH) != 0) mod_str[9] = 'x';
 
-  #ifndef _TARGET_GO32_
   if ((tm & S_ISUID) != 0) mod_str[3] = ((tm & S_IXUSR) != 0) ? 's' : 'S';
   if ((tm & S_ISGID) != 0) mod_str[6] = ((tm & S_IXGRP) != 0) ? 's' : 'S';
   if ((tm & S_ISVTX) != 0) mod_str[9] = ((tm & S_IXOTH) != 0) ? 't' : 'T';
-  #endif
-
-  #ifdef _TARGET_GO32_
-  mod_str[4]=mod_str[5]=mod_str[6]=mod_str[7]=mod_str[8]=mod_str[9]='-';
-  #endif
 }
 
 /*---------------------------------------------------------------------------*/
@@ -94,14 +85,12 @@ int  file_set_mode_str( const char *filename, const mode_str_t mod_str )
   if (new_mod_str[8] == 'w') new_mode |= S_IWOTH;
   if (new_mod_str[9] == 'x') new_mode |= S_IXOTH;
 
-  #ifndef _TARGET_GO32_
   if (new_mod_str[3] == 's') { new_mode |= S_ISUID; new_mode |= S_IXUSR; }
   if (new_mod_str[3] == 'S') new_mode |= S_ISUID;
   if (new_mod_str[6] == 's') { new_mode |= S_ISGID; new_mode |= S_IXGRP; }
   if (new_mod_str[6] == 'S') new_mode |= S_ISGID;
   if (new_mod_str[9] == 't') { new_mode |= S_ISVTX; new_mode |= S_IXOTH; }
   if (new_mod_str[9] == 'T') new_mode |= S_ISVTX;
-  #endif
 
   return ( chmod( filename, new_mode ) != 0 );
 }
@@ -136,27 +125,27 @@ int  vfu_edit_attr( mode_str_t mod_str, int allow_masking )
     for ( int z = 0; z < 16; z++ ) mode_i[z] = 2;
     }
 
-  const char* AONOFF1[] = { "YES", " - ", " ? ", NULL };
-  const char* AONOFF2[] = { "YES", " - ", NULL };
+  const wchar_t* AONOFF1[] = { L"YES", L" - ", L" ? ", NULL };
+  const wchar_t* AONOFF2[] = { L"YES", L" - ", NULL };
   #define AONOFF  ( allow_masking ? AONOFF1 : AONOFF2 )
   ToggleEntry mode_toggles[] =
   {
-  { ' ', "Read      Owner", &mode_i[ 1], AONOFF },
-  { ' ', "Write     Owner", &mode_i[ 2], AONOFF },
-  { ' ', "Exec/Srch Owner", &mode_i[ 3], AONOFF },
-  { ' ', "Read      Group", &mode_i[ 4], AONOFF },
-  { ' ', "Write     Group", &mode_i[ 5], AONOFF },
-  { ' ', "Exec/Srch Group", &mode_i[ 6], AONOFF },
-  { ' ', "Read      Other", &mode_i[ 7], AONOFF },
-  { ' ', "Write     Other", &mode_i[ 8], AONOFF },
-  { ' ', "Exec/Srch Other", &mode_i[ 9], AONOFF },
-  { ' ', "Set user  id",    &mode_i[10], AONOFF },
-  { ' ', "Set group id",    &mode_i[11], AONOFF },
-  { ' ', "Sticky  Bit",     &mode_i[12], AONOFF },
-  {  -1, "---",             NULL,        NULL },
+  { L' ', L"Read      Owner", &mode_i[ 1], AONOFF },
+  { L' ', L"Write     Owner", &mode_i[ 2], AONOFF },
+  { L' ', L"Exec/Srch Owner", &mode_i[ 3], AONOFF },
+  { L' ', L"Read      Group", &mode_i[ 4], AONOFF },
+  { L' ', L"Write     Group", &mode_i[ 5], AONOFF },
+  { L' ', L"Exec/Srch Group", &mode_i[ 6], AONOFF },
+  { L' ', L"Read      Other", &mode_i[ 7], AONOFF },
+  { L' ', L"Write     Other", &mode_i[ 8], AONOFF },
+  { L' ', L"Exec/Srch Other", &mode_i[ 9], AONOFF },
+  { L' ', L"Set user  id",    &mode_i[10], AONOFF },
+  { L' ', L"Set group id",    &mode_i[11], AONOFF },
+  { L' ', L"Sticky  Bit",     &mode_i[12], AONOFF },
+  {    0, L"---",             NULL,        NULL },
   };
 
-  if ( !vfu_toggle_box( 50, 5, "Change file Mode", mode_toggles ) ) return 0;
+  if ( !vfu_toggle_box( 50, 5, L"Change file Mode", mode_toggles ) ) return 0;
 
   if (mode_i[ 1] < 2) mod_str[1] = mode_i[ 1] == 0 ? 'r' : '-';
   if (mode_i[ 2] < 2) mod_str[2] = mode_i[ 2] == 0 ? 'w' : '-';
@@ -177,60 +166,6 @@ int  vfu_edit_attr( mode_str_t mod_str, int allow_masking )
 
 /*---------------------------------------------------------------------------*/
 
-#ifdef _TARGET_GO32_
-#include <dpmi.h>
-#include <go32.h>
-
-int file_get_sfn( const char *in, char *out )
-{
-  fname_t src;
-  fname_t dst;
-
-  strcpy( src, in );
-
-  __dpmi_regs r;
-  dosmemput(src, strlen (src)+1, __tb);
-  r.x.ax = 0x7160;    /* Truename */
-  r.x.cx = 1;     /* Get short name */
-  r.x.ds = r.x.es = __tb / 16;
-  r.x.si = r.x.di = __tb & 15;
-  __dpmi_int(0x21, &r);
-  if (r.x.flags & 1 || r.x.ax == 0x7100)
-    {
-    strcpy( out, in );
-    return -1;
-    }
-  dosmemget (__tb, MAX_PATH, dst);
-  strcpy( out, dst );
-  return 0;
-}
-
-int file_get_lfn( const char *in, char *out )
-{
-  fname_t src;
-  fname_t dst;
-
-  strcpy( src, in );
-
-  __dpmi_regs r;
-  dosmemput(src, strlen (src)+1, __tb);
-  r.x.ax = 0x7160;    /* Truename */
-  r.x.cx = 2;     /* Get long name */
-  r.x.ds = r.x.es = __tb / 16;
-  r.x.si = r.x.di = __tb & 15;
-  __dpmi_int(0x21, &r);
-  if (r.x.flags & 1 || r.x.ax == 0x7100)
-    {
-    strcpy( out, in );
-    return -1;
-    }
-  dosmemget (__tb, MAX_PATH, dst);
-  strcpy( out, dst );
-  return 0;
-}
-
-#endif /* _TARGET_GO32_ */
-
 /*###########################################################################*/
 
 /* eof vfusys.cpp */
