@@ -1,10 +1,11 @@
 /****************************************************************************
- *
- * Copyright (c) 1996-2021 Vladi Belperchinov-Shabanski "Cade" 
- * http://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
- *
- * SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
- *
+ #
+ # Copyright (c) 1996-2023 Vladi Belperchinov-Shabanski "Cade" 
+ # https://cade.noxrun.com/  <cade@noxrun.com> <cade@bis.bg>
+ # https://cade.noxrun.com/projects/vfu     https://github.com/cade-vs/vfu
+ #
+ # SEE `README',`LICENSE' OR `COPYING' FILE FOR LICENSE AND OTHER DETAILS!
+ #
  ****************************************************************************/
 
 #ifndef _VFUSYS_H_
@@ -14,19 +15,6 @@
 #include <sys/stat.h>
 #include <unistd.h>
 
-/*
-  following defines are taken from coreutils-5.2.1
-  Copyright (C) 1989, 1991-2004 Free Software Foundation, Inc.
-  to address the file size problem when file is larger than 2GB
-*/
-
-#ifndef CHAR_BIT
-# define CHAR_BIT 8
-#endif
-#define TYPE_SIGNED(t) (! ((t) 0 < (t) -1))
-#define TYPE_MINIMUM(t) ((t) (TYPE_SIGNED (t) ? ~ (t) 0 << (sizeof (t) * CHAR_BIT - 1) : (t) 0))
-#define TYPE_MAXIMUM(t) ((t) (~ (t) 0 - TYPE_MINIMUM (t)))
-
 /*
     VFU specific defines
 */
@@ -54,13 +42,8 @@ int  file_set_mode_str( const char *filename, const mode_str_t mod_str );
 int  vfu_edit_attr( mode_str_t mod_str, int allow_masking = 1 );
 
 /* FIXME: dir_exist should check if directory really */
-#define  dir_exist( d ) ( access( d, F_OK ) == 0)
-#define file_exist( d ) ( access( d, F_OK ) == 0)
-
-#ifdef _TARGET_GO32_
-int file_get_sfn( const char *in, char *out );
-int file_get_lfn( const char *in, char *out );
-#endif
+#define  dir_exist( d ) ( access( d, F_OK ) == 0 )
+#define file_exist( d ) ( access( d, F_OK ) == 0 )
 
 #endif /* _VFUSYS_H_ */
 
