@@ -39,19 +39,26 @@ VString s;
 int i = 0;
 int full = 0;
 
-// toggles
+// place-holders
 while( a_line[i] )
   {
   if ( a_line[i] == '%' )
     {
-    switch( a_line[i+1] )
+    char ch = a_line[i+1];
+    if( ! ch ) break;
+    
+    if( ch == 'h' || ch == 'H' ) // auto-sensing F or G depending on selection count
+      ch = sel_count > 0 ? ch == 'H' ? 'G' : 'g' : ch == 'H' ? 'F' : 'f';
+    
+    switch( ch )
       {
       case 'r' : /* rescan files after */
       case 'R' : a_options += "r"; 
                  break; 
 
       case 'f' : /* file name */
-      case 'F' : if( work_mode == WM_ARCHIVE )
+      case 'F' : full = ch == 'F';
+                 if( work_mode == WM_ARCHIVE )
                    {
                    s = files_list_get(FLI)->name();
                    }
@@ -67,7 +74,8 @@ while( a_line[i] )
                  break;
 
       case 'g' : /* list selected filenames */
-      case 'G' : int z;
+      case 'G' : full = ch == 'G';
+                 int z;
                  for( z = 0; z < files_list_count(); z++ )
                    {
                    TF *fi = files_list_get(z);
@@ -91,7 +99,7 @@ while( a_line[i] )
       case 'e' : /* name only */
       case 'E' : /* extension only */
                  if ( a_line[i+1] == 'e' )
-                   s = str_file_name( s );
+                   s = str_file_name( files_list_get(FLI)->name() );
                  else
                    s = files_list_get(FLI)->ext();
                  out += shell_escape( s );
@@ -249,16 +257,22 @@ char* time_str_compact( const time_t tim, char* buf )
   tm     tim_tm;
   localtime_r( &tim, &tim_tm );
   const char* tfm;
-  if (timenow > tim + 6L * 30L * 24L * 60L * 60L /* old */
-      ||
-      timenow < tim - 60L * 60L) /* in the future */
-      {
-      tfm = "%b %d  %Y";
-      }
-    else
-      {
-      tfm = "%b %d %H:%M";
-      }  
+  long int tdiff = timenow - tim;
+  if ( tdiff > 6L * 30L * 24L * 60L * 60L /* older than 6 months */
+       ||
+       tdiff < - 23L * 60L * 60L) /* in the future, past next 23 hours */
+    {
+    tfm = "%b %d  %Y";
+    }
+  else if( abs( tdiff ) < 23L * 60L * 60L )
+    {
+    /* in the near 23 hours */
+    tfm = "%a %H:%M:%S";
+    }
+  else
+    {
+    tfm = "%b %d %H:%M";
+    }  
   strftime( buf, 16, tfm, &tim_tm );
   return buf;
 }
