@@ -125,6 +125,13 @@
     set( tmp );
   }
 
+  void VS_STRING_CLASS::ll( const long long n )
+  {
+    VS_CHAR tmp[64];
+    VS_FN_SPRINTF( tmp, LENOF_VS_CHAR(tmp), VS_CHAR_L("%lld"), n );
+    set( tmp );
+  }
+
   void VS_STRING_CLASS::f( const double d )
   {
     VS_CHAR tmp[64];
@@ -611,12 +618,28 @@
     return  pc - target;
   }
 
-  int str_rfind( const VS_CHAR* target, const VS_CHAR c ) // returns last zero-based position of VS_CHAR, or -1 if not found
+  int str_rfind( const VS_CHAR* target, const VS_CHAR c, int startpos ) // returns last zero-based position of VS_CHAR, or -1 if not found
   {
-    const VS_CHAR* pc = VS_FN_STRRCHR( target, c );
-    if( ! pc )
-      return -1;
-    return  pc - target;
+    if( startpos == 0 )
+      {
+      const VS_CHAR* pc = VS_FN_STRRCHR( target, c );
+      if( ! pc )
+        return -1;
+      return  pc - target;
+      }
+    else
+      {
+      int sl = str_len( target );
+      int pos = startpos > 0 ? startpos : sl + startpos;
+      if( pos < 0 ) return -1;
+      if( pos >= sl ) pos = sl - 1;
+      while( pos > -1 )
+        {
+        if( target[pos] == c ) return pos;
+        pos--;
+        }
+      return pos;
+      }
   }
 
   int str_find( const VS_CHAR* target, const VS_CHAR* s, int startpos ) // returns first zero-based position of VS_STRING_CLASS, or -1 if not found
@@ -630,11 +653,22 @@
     return  pc - target;
   }
 
-  int str_rfind( const VS_CHAR* target, const VS_CHAR* s ) // returns last zero-based position of VS_STRING_CLASS, or -1 if not found
+  int str_rfind( const VS_CHAR* target, const VS_CHAR* s, int startpos ) // returns last zero-based position of VS_STRING_CLASS, or -1 if not found
   {
     int sl = str_len( target );
     int sls = str_len( s );
     int z = sl - sls;
+    if( startpos < 0 )
+      {
+      z += startpos;
+      if( z < 0 ) return -1;
+      }
+    else if( startpos > 0 )
+      {
+      if( startpos > z ) return -1;
+      z = startpos;
+      }  
+      
     while ( z > 0 )
       {
       if ( VS_FN_STRNCMP( target + z, s, sls ) == 0 ) return z;
@@ -1526,108 +1560,12 @@
 
   VS_TRIE_NODE::~VS_TRIE_NODE()
   {
+    //printf( "             ~DELETE: %p [%c]  ---> next: %p    down %p    data %p\n", this, c, next, down, data );
     if ( next ) delete next;
     if ( down ) delete down;
     if ( data ) delete data;
   }
 
-  void VS_TRIE_NODE::del_node( const VS_CHAR *key, int branch )
-  {
-    if ( !key ) return;
-    if ( !key[0] ) return;
-
-    if ( key[1] == 0 )
-      { // last VS_CHAR reached
-      if ( key[0] != c ) return;  // not found
-      // key found
-      if ( data ) delete data; // release key's value
-      data = NULL;
-      if ( down )
-        { // there are more keys below
-        if ( branch )
-          {
-          delete down; // delete all keys below
-          c = 0; // mark current as `not used'
-          }
-        }
-      else
-        { // there is no more keys below
-        c = 0; // mark current as `not used'
-        }
-      }
-    else
-      { // last VS_CHAR is not reached
-      if ( key[0] == c )
-        { // current VS_CHAR is in the key
-        if ( down )
-          { // try key down
-          down->del_node( key + 1, branch );
-          if ( down->c == 0 )
-            { // down node is not used--remove it
-            ASSERT( down->down == NULL );
-            VS_TRIE_NODE *tmp = down;
-            down = down->next;
-            delete tmp;
-            }
-          }
-        else
-          return; // not found
-        }
-      else
-        {
-        if ( next ) // VS_CHAR is not in the key, try next
-          {
-          next->del_node( key, branch );
-          if ( next->c == 0 )
-            { // down node is not used--remove it
-            ASSERT( next->down == NULL );
-            VS_TRIE_NODE *tmp = next;
-            next = next->next;
-            delete tmp;
-            }
-          }
-        else
-          return; // not found
-        }
-      }
-  }
-
-  VS_TRIE_NODE* VS_TRIE_NODE::find_node( const VS_CHAR* key, int create )
-  {
-    if ( !key || !key[0] ) return NULL;
-    if ( key[0] == c )
-      { // VS_CHAR in the current key
-      if ( key[1] == 0 )
-        { // last VS_CHAR and is in the key--found!
-        return this;
-        }
-      else
-        { // not last VS_CHAR...
-        if ( ! down && create )
-          { // nothing below but should create
-          down = new VS_TRIE_NODE();
-          down->c = key[1];
-          }
-        if ( down )
-          return down->find_node( key + 1, create ); // search below
-        else
-          return NULL; // not found
-        }
-      }
-    else
-      { // VS_CHAR not in the current key--try next
-      if ( ! next && create )
-        { // no next but should create
-        next = new VS_TRIE_NODE();
-        next->c = key[0];
-        }
-      if ( next )
-        return next->find_node( key, create ); // search next
-      else
-        return NULL; // not found
-      }
-  }
-
   VS_TRIE_NODE *VS_TRIE_NODE::clone()
   {
     VS_TRIE_NODE *tmp = new VS_TRIE_NODE();
@@ -1660,10 +1598,159 @@
   {
     VS_TRIE_BOX *new_box = new VS_TRIE_BOX();
     delete new_box->root;
-    new_box->root = root->clone();
+    new_box->root   = root->clone();
     return new_box;
   }
 
+  VS_TRIE_NODE* VS_TRIE_BOX::find_node( VS_TRIE_NODE* node, const VS_CHAR* key, int create )
+  {
+    if( ! key || ! key[0] ) return NULL;
+    if( key[0] == node->c )
+      { // VS_CHAR in the current key
+      if ( key[1] == 0 )
+        { // last VS_CHAR and is in the key--found!
+        return node;
+        }
+      else
+        { // not last VS_CHAR...
+        if ( ! node->down && create )
+          { // nothing below but should create
+          node->down = new VS_TRIE_NODE();
+          node->down->c = key[1];
+          }
+        if ( node->down )
+          return find_node( node->down, key + 1, create ); // search below
+        else
+          return NULL; // not found
+        }
+      }
+    else
+      { // VS_CHAR not in the current key--try next
+      if ( ! node->next && create )
+        { // no next but should create
+        node->next = new VS_TRIE_NODE();
+        node->next->c = key[0];
+        }
+      if ( node->next )
+        return find_node( node->next, key, create ); // search next
+      else
+        return NULL; // not found
+      }
+  }
+
+  int VS_TRIE_BOX::count_data_nodes( VS_TRIE_NODE* node )
+  {
+    if( ! node ) return 0;
+    return ( node->data ? 1 : 0 ) + count_data_nodes( node->next ) + count_data_nodes( node->down );
+  }
+/*
+  void VS_TRIE_BOX::del_node( VS_TRIE_NODE* node, const VS_CHAR *key, int branch )
+  {
+    VS_TRIE_NODE* del_node = find_node( node, key );
+    if( ! del_node ) return;
+    if( del_node->data )
+      {
+      delete del_node->data;
+      del_node->data = NULL;
+      }
+    if( branch && del_node->down )
+      {
+      delete del_node->down;
+      del_node->down = NULL;
+      }
+  }
+*/
+  void VS_TRIE_BOX::del_node( VS_TRIE_NODE* node, const VS_CHAR *key, int branch )
+  {
+    //printf( "%p --> [%c] data: %p    next: %p    down: %p    <-- key: %s\n", node, node->c, node->data, node->next, node->down, key );
+    if( ! key || ! key[0] ) return;
+    if( key[0] == node->c )
+      { // VS_CHAR in the current key
+      if ( key[1] == 0 )
+        { // last VS_CHAR and is in the key--found!
+        //printf( "FOUND: %p --> [%c] data: %p    next: %p    down: %p    <-- key: %s\n", node, node->c, node->data, node->next, node->down, key );
+        if( node->data )
+          {
+          delete node->data;
+          node->data = NULL;
+          }
+        if( branch && node->down )
+          {
+          //printf( "       DELETE: DOWN: %p [%c] -> %p\n", node, node->c, node->down );
+          delete node->down;
+          node->down = NULL;
+          }
+        }
+      else
+        { // not last VS_CHAR...
+        if ( node->down )
+          {
+          del_node( node->down, key + 1, branch ); // search below
+          if( ! node->down->data && ! node->down->down )
+            {
+            //printf( "       DELETE: AFTER DOWN: %p [%c] -> %p\n", node, node->c, node->down );
+            VS_TRIE_NODE* tmp = node->down;
+            node->down = node->down->next;
+            tmp->next = NULL;
+            delete tmp;
+            }
+          }
+        }
+      }
+    else
+      { // VS_CHAR not in the current key--try next
+      if ( node->next )
+        {
+        del_node( node->next, key, branch ); // search next
+        if( ! node->next->data && ! node->next->down )
+          {
+          //printf( "       DELETE: NEXT: %p [%c] -> %p\n", node, node->c, node->next );
+          VS_TRIE_NODE* tmp = node->next;
+          node->next = node->next->next;
+          tmp->next = NULL;
+          delete tmp;
+          }
+        }
+      }
+  }
+
+  int VS_TRIE_BOX::vacuum_node( VS_TRIE_NODE* node )
+  {
+    int vc = 0; // vacuum count
+    if( node->down ) 
+      {
+      vc += vacuum_node( node->down );
+      if( ! node->down->data && ! node->down->down )
+        {
+        VS_TRIE_NODE* tmp = node->down;
+        node->down = node->down->next;
+        delete tmp;
+        vc++;
+        }
+      }
+    
+    if( node->next ) 
+      {
+      vc += vacuum_node( node->next );
+      if( ! node->next->data && ! node->next->down )
+        {
+        VS_TRIE_NODE* tmp = node->next;
+        node->next = node->next->next;
+        delete tmp;
+        vc++;
+        }
+      }
+  
+    return vc;
+  }
+
+  int VS_TRIE_BOX::vacuum()
+  {
+    return vacuum_node( root );
+  }
+
+
+
 /***************************************************************************
 **
 ** VTRIE
@@ -1693,6 +1780,11 @@
     box->unref();
   }
 
+  int VS_TRIE_CLASS::count( const VS_CHAR* key ) 
+  { 
+    return box->count_data_nodes( key ? box->find_node( box->root, key ) : box->root ); 
+  }
+
   void VS_TRIE_CLASS::detach()
   {
     if ( box->refs() == 1 ) return;
@@ -1715,11 +1807,19 @@
     if ( node->next ) trace_node( node->next, keys, vals );
   }
 
+  void VS_TRIE_CLASS::print_trace_node( VS_TRIE_NODE *node, int level )
+  {
+    for( int i = 0; i < level*8; i++ ) printf( " " );
+    printf( "%p --> [%c] data: %p    next: %p    down: %p\n", (void*)node, node->c, (void*)(node->data), (void*)(node->next), (void*)(node->down) );
+    if ( node->down ) print_trace_node( node->down, level + 1 );
+    if ( node->next ) print_trace_node( node->next, level );
+  }
+
   void VS_TRIE_CLASS::set( const VS_CHAR* key, const VS_CHAR* value )
   {
     if ( !value || !key || !key[0] ) return;
     detach();
-    VS_TRIE_NODE *node = box->root->find_node( key, 1 );
+    VS_TRIE_NODE *node = box->find_node( box->root, key, 1 );
     ASSERT( node );
     if ( ! node->data )
       node->data = new VS_STRING_CLASS();
@@ -1729,23 +1829,23 @@
   const VS_CHAR* VS_TRIE_CLASS::get( const VS_CHAR* key )
   {
     if ( !key || !key[0] ) return NULL;
-    VS_TRIE_NODE *node = box->root->find_node( key );
+    VS_TRIE_NODE *node = box->find_node( box->root, key );
     if ( node && node->data )
       return node->data->data();
     else
       return NULL;
   }
 
-  void VS_TRIE_CLASS::del( const VS_CHAR* key )
+  void VS_TRIE_CLASS::del( const VS_CHAR* key, int branch )
   {
     if ( !key || !key[0] ) return;
     detach();
-    box->root->del_node( key );
+    box->del_node( box->root, key, branch );
   }
 
   int VS_TRIE_CLASS::exists( const VS_CHAR* key ) // return != 0 if key exist (with data)
   {
-    VS_TRIE_NODE *node = box->root->find_node( key );
+    VS_TRIE_NODE *node = box->find_node( box->root, key );
     if ( node && node->data )
       return 1;
     else
@@ -1852,6 +1952,11 @@
       }
   }
 
+  void VS_TRIE_CLASS::print_trace()
+  {
+    print_trace_node( box->root, 0 );
+  }
+
 /****************************************************************************
 **
 ** VS_STRING_CLASS Utilities -- functions and classes
