@@ -97,11 +97,12 @@ public:
     };
 
   VS_STRING_CLASS()                      {  box = new VS_STRING_BOX(); };
-  VS_STRING_CLASS( const void*    nu  )  {  box = new VS_STRING_BOX(); nu = nu;  };
-  VS_STRING_CLASS( const VS_CHAR* ps  )  {  box = new VS_STRING_BOX(); set( ps); };
-  VS_STRING_CLASS( const int      n   )  {  box = new VS_STRING_BOX(); i(n);     };
-  VS_STRING_CLASS( const long     n   )  {  box = new VS_STRING_BOX(); l(n);     };
-  VS_STRING_CLASS( const double   n   )  {  box = new VS_STRING_BOX(); f(n);     };
+  VS_STRING_CLASS( const void*     nu )  {  box = new VS_STRING_BOX(); nu = nu;  };
+  VS_STRING_CLASS( const VS_CHAR*  ps )  {  box = new VS_STRING_BOX(); set( ps); };
+  VS_STRING_CLASS( const int       n  )  {  box = new VS_STRING_BOX(); i(n);     };
+  VS_STRING_CLASS( const long      n  )  {  box = new VS_STRING_BOX(); l(n);     };
+  VS_STRING_CLASS( const long long n  )  {  box = new VS_STRING_BOX(); ll(n);    };
+  VS_STRING_CLASS( const double    n  )  {  box = new VS_STRING_BOX(); f(n);     };
   VS_STRING_CLASS( VS_STRING_CLASS_R  rs  );
   ~VS_STRING_CLASS() { box->unref(); };
 
@@ -125,19 +126,21 @@ public:
         return *this;
         };
 
-  const VS_STRING_CLASS& operator  = ( const void*    nu   ) { nu = nu; undef(); return *this; };
-  const VS_STRING_CLASS& operator  = ( const VS_CHAR* ps   ) { set(ps); return *this; };
-  const VS_STRING_CLASS& operator  = ( const int      n    ) { i(n);    return *this; };
-  const VS_STRING_CLASS& operator  = ( const long     n    ) { l(n);    return *this; };
-  const VS_STRING_CLASS& operator  = ( const double   n    ) { f(n);    return *this; };
+  const VS_STRING_CLASS& operator  = ( const void*     nu  ) { nu = nu; undef(); return *this; };
+  const VS_STRING_CLASS& operator  = ( const VS_CHAR*  ps  ) { set(ps); return *this; };
+  const VS_STRING_CLASS& operator  = ( const int       n   ) { i(n);    return *this; };
+  const VS_STRING_CLASS& operator  = ( const long      n   ) { l(n);    return *this; };
+  const VS_STRING_CLASS& operator  = ( const long long n   ) { ll(n);   return *this; };
+  const VS_STRING_CLASS& operator  = ( const double    n   ) { f(n);    return *this; };
 
   const VS_STRING_CLASS& operator += ( const VS_STRING_CLASS& str )  { cat( str.box->s ); return *this; };
-  const VS_STRING_CLASS& operator += ( const VS_CHAR*  ps    )       { cat( ps ); return *this; };
-  const VS_STRING_CLASS& operator += ( const int    n     )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
-  const VS_STRING_CLASS& operator += ( const long   n     )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
-  const VS_STRING_CLASS& operator += ( const double n     )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
+  const VS_STRING_CLASS& operator += ( const VS_CHAR*  ps )          { cat( ps ); return *this; };
+  const VS_STRING_CLASS& operator += ( const int       n  )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
+  const VS_STRING_CLASS& operator += ( const long      n  )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
+  const VS_STRING_CLASS& operator += ( const long long n  )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
+  const VS_STRING_CLASS& operator += ( const double    n  )          { VS_STRING_CLASS tmp = n; cat(tmp); return *this; };
 
-  const VS_STRING_CLASS& operator *= ( const int    n     )          { return str_mul( *this, n ); };
+  const VS_STRING_CLASS& operator *= ( const int       n  )          { return str_mul( *this, n ); };
 
   friend VS_STRING_CLASS operator + ( const VS_STRING_CLASS& str1, const VS_STRING_CLASS& str2 ) { VS_STRING_CLASS res = str1; res += str2; return res; };
   friend VS_STRING_CLASS operator + ( const VS_STRING_CLASS& str1, const VS_CHAR* ps )           { VS_STRING_CLASS res = str1; res += ps;   return res; };
@@ -202,11 +205,13 @@ public:
 
   void   i( const int n );
   void   l( const long n );
+  void   ll( const long long n );
   void   f( const double d );
   void   fi( const double d ); // sets double as int (w/o frac)
 
   int    i()  { return VS_FN_STRTOL( box->s ); }
   long   l()  { return VS_FN_STRTOL( box->s ); }
+  long long ll()  { return VS_FN_STRTOLL( box->s ); }
   double f()  { return VS_FN_STRTOD( box->s ); }
   double fi() { return VS_FN_STRTOD( box->s ); }
 
@@ -387,9 +392,9 @@ public:
 ****************************************************************************/
 
   int str_find ( const VS_CHAR* target, const VS_CHAR  c, int startpos = 0 ); // returns first zero-based position of VS_CHAR, or -1 if not found
-  int str_rfind( const VS_CHAR* target, const VS_CHAR  c                   ); // returns last  zero-based position of VS_CHAR, or -1 if not found
+  int str_rfind( const VS_CHAR* target, const VS_CHAR  c, int startpos = 0 ); // returns last  zero-based position of VS_CHAR, or -1 if not found. if startpos is negative, will be skipped from the end, if positive will be absolute post to start from.
   int str_find ( const VS_CHAR* target, const VS_CHAR* s, int startpos = 0 ); // returns first zero-based position of VS_STRING_CLASS, or -1 if not found
-  int str_rfind( const VS_CHAR* target, const VS_CHAR* s                   ); // returns last  zero-based position of VS_STRING_CLASS, or -1 if not found
+  int str_rfind( const VS_CHAR* target, const VS_CHAR* s, int startpos = 0 ); // returns last  zero-based position of VS_STRING_CLASS, or -1 if not found. if startpos is negative, will be skipped from the end, if positive will be absolute post to start from.
 
   int str_count(     const VS_CHAR* target, const VS_CHAR* charlist, int startpos = 0 ); // returns match count of all VS_CHARs from `charlist'
   int str_str_count( const VS_CHAR* target, const VS_CHAR* s,        int startpos = 0 ); // returns match count of `s' VS_STRING_CLASS into target
@@ -561,8 +566,6 @@ public:
   VS_STRING_CLASS   *data;
 
   void detach() { next = down = NULL; }
-  void del_node( const VS_CHAR *key, int branch = 0 );
-  VS_TRIE_NODE* find_node( const VS_CHAR* key, int create = 0 );
 
   VS_TRIE_NODE *clone();
   void print();
@@ -583,8 +586,16 @@ public:
   VS_TRIE_BOX()  { root = new VS_TRIE_NODE(); }
   ~VS_TRIE_BOX() { ASSERT( root ); delete root; }
 
+  VS_TRIE_NODE* find_node( VS_TRIE_NODE* node, const VS_CHAR* key, int create = 0 );
+  void del_node( VS_TRIE_NODE* node, const VS_CHAR *key, int branch = 0 );
+
+  int count_data_nodes( VS_TRIE_NODE* node );
+
   VS_TRIE_BOX* clone();
   void undef() { ASSERT( root ); delete root; root = new VS_TRIE_NODE(); };
+
+  int vacuum_node( VS_TRIE_NODE* node );
+  int vacuum();
 };
 
 /***************************************************************************
@@ -599,6 +610,7 @@ class VS_TRIE_CLASS
 
   void detach();
   void trace_node( VS_TRIE_NODE *node, VS_ARRAY_CLASS* keys, VS_ARRAY_CLASS *vals );
+  void print_trace_node( VS_TRIE_NODE *node, int level );
 
   VS_STRING_CLASS temp_key;
 
@@ -611,8 +623,12 @@ class VS_TRIE_CLASS
   VS_TRIE_CLASS( const VS_TRIE_CLASS& tr );
   ~VS_TRIE_CLASS();
 
+  int vacuum() { return box->vacuum(); };
+
+  int count( const VS_CHAR* key = NULL );
+
   void set( const VS_CHAR* key, const VS_CHAR* data ); // set data, same as []=
-  void del( const VS_CHAR* key                   ); // remove data associated with `key'
+  void del( const VS_CHAR* key, int branch = 0      ); // remove data associated with `key' or all data below this branch
   const VS_CHAR* get( const VS_CHAR* key            ); // get data by `key', same as []
 
   int exists( const VS_CHAR* key ); // return != 0 if key exist (i.e. is used)
@@ -632,6 +648,7 @@ class VS_TRIE_CLASS
 
   //void print_nodes() { print_node( root ); }; // for debug only
   void print(); // print trie data to stdout (console)
+  void print_trace(); // print trie data structure details
 
   int fload( const char* fname ); // return 0 for ok
   int fsave( const char* fname ); // return 0 for ok
@@ -641,7 +658,7 @@ class VS_TRIE_CLASS
   VS_STRING_CLASS& operator []( const VS_CHAR* key )
     {
     detach(); // I don't know if user will change returned VS_STRING_CLASS?!
-    VS_TRIE_NODE *node = box->root->find_node( key, 1 );
+    VS_TRIE_NODE *node = box->find_node( box->root, key, 1 );
     ASSERT( node );
     if ( ! node->data )
       node->data = new VS_STRING_CLASS();
