@@ -53,6 +53,17 @@ void test1()
   wprintf( L"************************ test 1 result is: %ls\n", str.data() ); // this should print `hello world'
 
   ASSERT( str == L"hello world" );
+
+  ASSERT( str_rfind( str, L'l'     ) == 9 );
+  ASSERT( str_rfind( str, L'l', -3 ) == 3 );
+  ASSERT( str_rfind( str, L'o',  7 ) == 7 );
+  ASSERT( str_rfind( str, L'o',  6 ) == 4 );
+
+  str = L"hello mello tello start!";
+
+  ASSERT( str_rfind( str, L"llo"      ) == 14 );
+  ASSERT( str_rfind( str, L"llo", -12 ) ==  8 );
+  ASSERT( str_rfind( str, L"llo",   7 ) ==  2 );
   
   str.compact( 1 );
   str.fix();
@@ -271,12 +282,12 @@ void test4()
     setp += L"this is, just a simple. but fixed, nonsense test, voila :)";
     }
 
-  printf( "set  = %ld\n", str_len( set  ) );
-  printf( "cat  = %ld\n", str_len( cat  ) );
-  printf( "setn = %ld\n", str_len( setn ) );
-  printf( "catn = %ld\n", str_len( catn ) );
-  printf( "sete = %ld\n", str_len( sete ) );
-  printf( "setp = %ld\n", str_len( setp ) );
+  printf( "set  = %zd\n", str_len( set  ) );
+  printf( "cat  = %zd\n", str_len( cat  ) );
+  printf( "setn = %zd\n", str_len( setn ) );
+  printf( "catn = %zd\n", str_len( catn ) );
+  printf( "sete = %zd\n", str_len( sete ) );
+  printf( "setp = %zd\n", str_len( setp ) );
 
   printf( "--------------------\n" );
 
